@@ -1,49 +1,52 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2014.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <QApplication>
-#include <QDialog>
-#include <QPushButton>
-#include <QListWidget>
-#include <QHBoxLayout>
-#include <QVBoxLayout>
-#include <QPushButton>
-#include <QStandardItemModel>
+#include "activities/action/SActivityLauncher.hpp"
 
-#include <fwRuntime/Convert.hpp>
+#include <fwActivities/IActivityValidator.hpp>
+#include <fwActivities/IBuilder.hpp>
+#include <fwActivities/IValidator.hpp>
 
+#include <fwCom/Signal.hpp>
+#include <fwCom/Signal.hxx>
 #include <fwCom/Slot.hpp>
 #include <fwCom/Slots.hpp>
 #include <fwCom/Slots.hxx>
 
-#include <fwTools/UUID.hpp>
-#include <fwTools/fwID.hpp>
-
-#include <fwServices/Base.hpp>
-#include <fwServices/registry/AppConfig.hpp>
-#include <fwServices/registry/ActiveWorkers.hpp>
-#include <fwServices/AppConfigManager.hpp>
-
 #include <fwData/Composite.hpp>
 #include <fwData/String.hpp>
 #include <fwData/Vector.hpp>
-#include <fwMedData/ActivitySeries.hpp>
-
-#include <fwComEd/VectorMsg.hpp>
-
-#include <fwGui/dialog/SelectorDialog.hpp>
-#include <fwGui/dialog/MessageDialog.hpp>
 
 #include <fwDataCamp/getObject.hpp>
 
-#include <fwActivities/IBuilder.hpp>
-#include <fwActivities/IValidator.hpp>
+#include <fwGui/dialog/MessageDialog.hpp>
+#include <fwGui/dialog/SelectorDialog.hpp>
 
-#include "activities/helper/Activity.hpp"
-#include "activities/action/SActivityLauncher.hpp"
+#include <fwMedData/ActivitySeries.hpp>
+
+#include <fwRuntime/Bundle.hpp>
+#include <fwRuntime/Convert.hpp>
+#include <fwRuntime/operations.hpp>
+
+#include <fwServices/IAppConfigManager.hpp>
+#include <fwServices/macros.hpp>
+#include <fwServices/registry/ActiveWorkers.hpp>
+#include <fwServices/registry/AppConfig.hpp>
+
+#include <fwTools/UUID.hpp>
+
+#include <boost/foreach.hpp>
+
+#include <QApplication>
+#include <QDialog>
+#include <QHBoxLayout>
+#include <QListWidget>
+#include <QPushButton>
+#include <QStandardItemModel>
+#include <QVBoxLayout>
 
 Q_DECLARE_METATYPE(::fwActivities::registry::ActivityInfo)
 
@@ -58,36 +61,32 @@ fwServicesRegisterMacro( ::fwGui::IActionSrv, ::activities::action::SActivityLau
 
 //------------------------------------------------------------------------------
 
-const ::fwCom::Slots::SlotKeyType SActivityLauncher::s_LAUNCH_SERIES_SLOT = "launchSeries";
-const ::fwCom::Signals::SignalKeyType SActivityLauncher::s_ACTIVITY_LAUNCHED_SIG = "activityLaunched";
+const ::fwCom::Slots::SlotKeyType SActivityLauncher::s_LAUNCH_SERIES_SLOT          = "launchSeries";
+const ::fwCom::Slots::SlotKeyType SActivityLauncher::s_LAUNCH_ACTIVITY_SERIES_SLOT = "launchActivitySeries";
+const ::fwCom::Slots::SlotKeyType SActivityLauncher::s_UPDATE_STATE_SLOT           = "updateState";
+const ::fwCom::Signals::SignalKeyType SActivityLauncher::s_ACTIVITY_LAUNCHED_SIG   = "activityLaunched";
 
 //------------------------------------------------------------------------------
 
-SActivityLauncher::SActivityLauncher() throw():
+SActivityLauncher::SActivityLauncher() noexcept :
     m_mode("message")
 {
-    m_sigActivityLaunched = ActivityLaunchedSignalType::New();
-    m_signals( s_ACTIVITY_LAUNCHED_SIG,  m_sigActivityLaunched);
+    m_sigActivityLaunched = newSignal< ActivityLaunchedSignalType >(s_ACTIVITY_LAUNCHED_SIG);
 
-    m_slotLaunchSeries = ::fwCom::newSlot( &SActivityLauncher::launchSeries, this ) ;
-
-    ::fwCom::HasSlots::m_slots( s_LAUNCH_SERIES_SLOT, m_slotLaunchSeries );
-
-#ifdef COM_LOG
-    ::fwCom::HasSlots::m_slots.setID();
-    ::fwCom::HasSignals::m_signals.setID();
-#endif
-    this->setWorker( m_associatedWorker );
+    newSlot(s_LAUNCH_SERIES_SLOT, &SActivityLauncher::launchSeries, this);
+    newSlot(s_LAUNCH_ACTIVITY_SERIES_SLOT, &SActivityLauncher::launchActivitySeries, this);
+    newSlot(s_UPDATE_STATE_SLOT, &SActivityLauncher::updateState, this);
 }
 
 //------------------------------------------------------------------------------
 
-SActivityLauncher::~SActivityLauncher() throw()
-{}
+SActivityLauncher::~SActivityLauncher() noexcept
+{
+}
 
 //------------------------------------------------------------------------------
 
-void SActivityLauncher::starting() throw(::fwTools::Failed)
+void SActivityLauncher::starting()
 {
     this->actionServiceStarting();
     this->updateState();
@@ -95,7 +94,7 @@ void SActivityLauncher::starting() throw(::fwTools::Failed)
 
 //------------------------------------------------------------------------------
 
-void SActivityLauncher::stopping() throw(::fwTools::Failed)
+void SActivityLauncher::stopping()
 {
     SLM_TRACE_FUNC();
     this->actionServiceStopping();
@@ -103,85 +102,85 @@ void SActivityLauncher::stopping() throw(::fwTools::Failed)
 
 //------------------------------------------------------------------------------
 
-void SActivityLauncher::configuring() throw(fwTools::Failed)
+void SActivityLauncher::configuring()
 {
     this->::fwGui::IActionSrv::initialize();
     typedef ::fwServices::IService::ConfigType ConfigType;
 
     m_parameters.clear();
-    if(this->getConfigTree().get_child("service").count("config") > 0)
+    if(this->getConfigTree().count("config") > 0)
     {
-        SLM_ASSERT("Sorry you must have one (and only one) <config/> element.",
-                this->getConfigTree().get_child("service").count("config") == 1 );
+        SLM_ASSERT("There must be one (and only one) <config/> element.",
+                   this->getConfigTree().count("config") == 1 );
 
-        const ::fwServices::IService::ConfigType srvconfig = this->getConfigTree().get_child("service");
-        const ::fwServices::IService::ConfigType &config = srvconfig.get_child("config");
+        const ::fwServices::IService::ConfigType srvconfig = this->getConfigTree();
+        const ::fwServices::IService::ConfigType& config   = srvconfig.get_child("config");
 
         m_mode = config.get_optional<std::string>("mode").get_value_or("message");
-        SLM_ASSERT("SActivityLauncher mode must be 'immediate' or 'message'",
+        SLM_ASSERT("SActivityLauncher mode must be either 'immediate' or 'message'",
                    "message" == m_mode || "immediate" == m_mode);
 
         if(config.count("parameters") == 1 )
         {
-            const ::fwServices::IService::ConfigType &configParameters = config.get_child("parameters");
-            BOOST_FOREACH( const ConfigType::value_type &v, configParameters.equal_range("parameter") )
+            const ::fwServices::IService::ConfigType& configParameters = config.get_child("parameters");
+            BOOST_FOREACH( const ConfigType::value_type &v,  configParameters.equal_range("parameter") )
             {
                 ParametersType::value_type parameter( v.second );
                 m_parameters.push_back( parameter );
             }
         }
-        OSLM_ASSERT("At most 1 <parameters> tag is allowed", config.count("parameters") < 2);
+        OSLM_ASSERT("A maximum of 1 <parameters> tag is allowed", config.count("parameters") < 2);
 
         if(config.count("filter") == 1 )
         {
-            const ::fwServices::IService::ConfigType &configFilter = config.get_child("filter");
-            OSLM_ASSERT("At most 1 <mode> tag is allowed", configFilter.count("mode") < 2);
+            const ::fwServices::IService::ConfigType& configFilter = config.get_child("filter");
+            OSLM_ASSERT("A maximum of 1 <mode> tag is allowed", configFilter.count("mode") < 2);
 
             const std::string mode = configFilter.get< std::string >("mode");
-            OSLM_ASSERT("'" << mode << "' value for <mode> tag isn't valid. Allowed values are : 'include', 'exclude'.", mode == "include" || mode == "exclude");
+            OSLM_ASSERT("'" << mode << "' value for <mode> tag isn't valid. Allowed values are : 'include', 'exclude'.",
+                        mode == "include" || mode == "exclude");
             m_filterMode = mode;
 
-            BOOST_FOREACH( const ConfigType::value_type &v, configFilter.equal_range("id") )
+            BOOST_FOREACH( const ConfigType::value_type &v,  configFilter.equal_range("id") )
             {
                 m_keys.push_back(v.second.get<std::string>(""));
             }
         }
-        OSLM_ASSERT("At most 1 <filter> tag is allowed", config.count("filter") < 2);
+        OSLM_ASSERT("A maximum of 1 <filter> tag is allowed", config.count("filter") < 2);
 
         if(config.count("quickLaunch") == 1 )
         {
             m_quickLaunch.clear();
-            const ::fwServices::IService::ConfigType &configQuickLaunch = config.get_child("quickLaunch");
-            BOOST_FOREACH( const ConfigType::value_type &v, configQuickLaunch.equal_range("association") )
+            const ::fwServices::IService::ConfigType& configQuickLaunch = config.get_child("quickLaunch");
+            BOOST_FOREACH( const ConfigType::value_type &v,  configQuickLaunch.equal_range("association") )
             {
-                const ::fwServices::IService::ConfigType &association = v.second;
-                const ::fwServices::IService::ConfigType xmlattr = association.get_child("<xmlattr>");
+                const ::fwServices::IService::ConfigType& association = v.second;
+                const ::fwServices::IService::ConfigType xmlattr      = association.get_child("<xmlattr>");
 
-                SLM_FATAL_IF( "Sorry, attribute \"type\" is missing", xmlattr.count("type") != 1 );
-                SLM_FATAL_IF( "Sorry, attribute \"id\" is missing", xmlattr.count("id") != 1 );
+                SLM_FATAL_IF( "The attribute \"type\" is missing", xmlattr.count("type") != 1 );
+                SLM_FATAL_IF( "The attribute \"id\" is missing", xmlattr.count("id") != 1 );
 
                 std::string type = xmlattr.get<std::string>("type");
-                std::string id = xmlattr.get<std::string>("id");
+                std::string id   = xmlattr.get<std::string>("id");
 
                 m_quickLaunch[type] = id;
             }
         }
-        SLM_ASSERT("At most 1 <quickLaunch> tag is allowed", config.count("quickLaunch") < 2);
+        SLM_ASSERT("A maximum of 1 <quickLaunch> tag is allowed", config.count("quickLaunch") < 2);
     }
 }
 
 //------------------------------------------------------------------------------
 
-::fwActivities::registry::ActivityInfo SActivityLauncher::show( const ActivityInfoContainer & infos )
+::fwActivities::registry::ActivityInfo SActivityLauncher::show( const ActivityInfoContainer& infos )
 {
-    QWidget *parent = qApp->activeWindow();
+    QWidget* parent = qApp->activeWindow();
 
     QDialog* dialog = new QDialog(parent);
     dialog->setWindowTitle(QString::fromStdString("Choose an activity"));
 
-
-    QStandardItemModel *model = new QStandardItemModel(dialog);
-    BOOST_FOREACH( ::fwActivities::registry::ActivityInfo info, infos)
+    QStandardItemModel* model = new QStandardItemModel(dialog);
+    for( ::fwActivities::registry::ActivityInfo info :  infos)
     {
         std::string text;
         if(info.title.empty())
@@ -199,9 +198,8 @@ void SActivityLauncher::configuring() throw(fwTools::Failed)
         model->appendRow(item);
     }
 
-
-    QListView * selectionList = new QListView();
-    selectionList->setIconSize(QSize(100,100));
+    QListView* selectionList = new QListView();
+    selectionList->setIconSize(QSize(100, 100));
     selectionList->setUniformItemSizes(true);
     selectionList->setModel(model);
 
@@ -211,14 +209,14 @@ void SActivityLauncher::configuring() throw(fwTools::Failed)
         selectionList->selectionModel()->select( index, QItemSelectionModel::Select );
     }
 
-    QPushButton* okButton = new QPushButton("Ok");
+    QPushButton* okButton     = new QPushButton("Ok");
     QPushButton* cancelButton = new QPushButton("Cancel");
 
-    QHBoxLayout *hLayout = new QHBoxLayout();
+    QHBoxLayout* hLayout = new QHBoxLayout();
     hLayout->addWidget(okButton);
     hLayout->addWidget(cancelButton);
 
-    QVBoxLayout *vLayout = new QVBoxLayout();
+    QVBoxLayout* vLayout = new QVBoxLayout();
     vLayout->addWidget(selectionList);
     vLayout->addLayout(hLayout);
 
@@ -231,8 +229,8 @@ void SActivityLauncher::configuring() throw(fwTools::Failed)
     if(dialog->exec())
     {
         QModelIndex currentIndex = selectionList->selectionModel()->currentIndex();
-        QStandardItem *item = model->itemFromIndex( currentIndex );
-        QVariant var = item->data();
+        QStandardItem* item      = model->itemFromIndex( currentIndex );
+        QVariant var             = item->data();
         info = var.value< ::fwActivities::registry::ActivityInfo >();
     }
 
@@ -273,7 +271,7 @@ SActivityLauncher::ActivityInfoContainer SActivityLauncher::getEnabledActivities
 
 //------------------------------------------------------------------------------
 
-void SActivityLauncher::updating() throw(::fwTools::Failed)
+void SActivityLauncher::updating()
 {
     ::fwData::Vector::sptr selection = this->getObject< ::fwData::Vector >();
 
@@ -283,7 +281,7 @@ void SActivityLauncher::updating() throw(::fwTools::Failed)
         ActivityInfoContainer infos = ::fwActivities::registry::Activities::getDefault()->getInfos(selection);
         infos = this->getEnabledActivities(infos);
 
-        if ( ! infos.empty())
+        if ( !infos.empty())
         {
             ::fwActivities::registry::ActivityInfo info;
             if((m_keys.size() == 1 && m_filterMode == "include") || (infos.size() == 1))
@@ -311,13 +309,6 @@ void SActivityLauncher::updating() throw(::fwTools::Failed)
 
 //------------------------------------------------------------------------------
 
-void SActivityLauncher::receiving( ::fwServices::ObjectMsg::csptr msg ) throw(::fwTools::Failed)
-{
-    this->updateState();
-}
-
-//------------------------------------------------------------------------------
-
 void SActivityLauncher::updateState()
 {
     ::fwData::Vector::sptr selection = this->getObject< ::fwData::Vector >();
@@ -327,7 +318,29 @@ void SActivityLauncher::updateState()
     if(selection->size() == 1 && ::fwMedData::ActivitySeries::dynamicCast((*selection)[0]))
     {
         ::fwMedData::ActivitySeries::sptr as = ::fwMedData::ActivitySeries::dynamicCast((*selection)[0]);
-        isExecutable = ::fwActivities::registry::Activities::getDefault()->hasInfo(as->getActivityConfigId());
+
+        if(m_filterMode == "include" || m_filterMode == "exclude")
+        {
+            const bool isIncludeMode = m_filterMode == "include";
+
+            KeysType::iterator keyIt = std::find(m_keys.begin(), m_keys.end(), as->getActivityConfigId());
+
+            if(keyIt != m_keys.end() && isIncludeMode)
+            {
+                isExecutable = true;
+            }
+            else if(keyIt == m_keys.end() && !isIncludeMode)
+            {
+                isExecutable = true;
+            }
+            isExecutable &= ::fwActivities::registry::Activities::getDefault()->hasInfo(
+                as->getActivityConfigId());
+        }
+        else
+        {
+            isExecutable = ::fwActivities::registry::Activities::getDefault()->hasInfo(
+                as->getActivityConfigId());
+        }
     }
     else
     {
@@ -353,12 +366,14 @@ void SActivityLauncher::updateState()
 
 //------------------------------------------------------------------------------
 
-void SActivityLauncher::info( std::ostream &_sstream )
-{}
+void SActivityLauncher::info( std::ostream& _sstream )
+{
+}
 
 //------------------------------------------------------------------------------
 
-void SActivityLauncher::buildActivity(const ::fwActivities::registry::ActivityInfo & info, const ::fwData::Vector::sptr& selection)
+void SActivityLauncher::buildActivity(const ::fwActivities::registry::ActivityInfo& info,
+                                      const ::fwData::Vector::sptr& selection)
 {
     ::fwData::Composite::sptr replaceMap = ::fwData::Composite::New();
     ::fwActivities::IBuilder::sptr builder;
@@ -368,34 +383,61 @@ void SActivityLauncher::buildActivity(const ::fwActivities::registry::ActivityIn
     ::fwMedData::ActivitySeries::sptr actSeries;
     actSeries = builder->buildData(info, selection);
 
-    if( ! actSeries )
+    if( !actSeries )
     {
-        OSLM_INFO("Activity <" << info.builderImpl << ">launch aborted");
+        std::string msg = "The activity <" + info.title + "> can't be launched. Builder <" + info.builderImpl +
+                          "> failed.";
+        ::fwGui::dialog::MessageDialog::showMessageDialog( "Activity can not be launched", msg,
+                                                           ::fwGui::dialog::IMessageDialog::WARNING);
+        OSLM_ERROR(msg);
         return;
     }
 
+    // Applies activity validator on activity series to check the data
+    if (!info.validatorsImpl.empty())
+    {
+        for (std::string validatorImpl : info.validatorsImpl)
+        {
+            /// Process activity validator
+            ::fwActivities::IValidator::sptr validator = ::fwActivities::validator::factory::New(validatorImpl);
+
+            ::fwActivities::IActivityValidator::sptr activityValidator =
+                ::fwActivities::IActivityValidator::dynamicCast(validator);
+
+            if (activityValidator)
+            {
+                ::fwActivities::IValidator::ValidationType validation = activityValidator->validate(actSeries);
+                if(!validation.first)
+                {
+                    std::string message = "The activity '" + info.title + "' can not be launched:\n" +
+                                          validation.second;
+                    ::fwGui::dialog::MessageDialog::showMessageDialog("Activity launch",
+                                                                      message,
+                                                                      ::fwGui::dialog::IMessageDialog::CRITICAL);
+                    return;
+                }
+            }
+        }
+    }
+
     ParametersType parameters = this->translateParameters(m_parameters);
-    ::fwServices::ObjectMsg::sptr msg = helper::buildActivityMsg(actSeries, info, parameters);
+    ::fwActivities::registry::ActivityMsg msg = ::fwActivities::registry::ActivityMsg(actSeries, info, parameters);
 
     if( m_mode == "message" )
     {
-        fwServicesNotifyMsgMacro(this->getLightID(), m_sigActivityLaunched, msg);
+        m_sigActivityLaunched->asyncEmit(msg);
     }
     else
     {
         ::fwGui::LockAction lock(this->getSptr());
-        ::fwData::String::csptr msgData = ::fwData::String::dynamicConstCast(msg->getDataInfo("NEW_CONFIGURATION_HELPER"));
-        const std::string viewConfigFieldID = "VIEWCONFIGID";
-        const std::string fieldID           = "APPCONFIG";
 
-        std::string viewConfigID = msgData->getField(viewConfigFieldID, ::fwData::String::New(""))->value();
-        ::fwData::Composite::sptr replaceMap = msgData->getField(fieldID, ::fwData::Composite::New());
+        std::string viewConfigID = msg.getAppConfigID();
+        ::fwActivities::registry::ActivityMsg::ReplaceMapType replaceMap = msg.getReplaceMap();
+        replaceMap["GENERIC_UID"]                                        =
+            ::fwServices::registry::AppConfig::getUniqueIdentifier();
 
-        ::fwRuntime::ConfigurationElement::csptr config =
-            ::fwServices::registry::AppConfig::getDefault()->getAdaptedTemplateConfig( viewConfigID, replaceMap);
-
-        ::fwServices::AppConfigManager::sptr helper = ::fwServices::AppConfigManager::New();
-        helper->setConfig( config );
+        ::fwServices::IAppConfigManager::sptr helper = ::fwServices::IAppConfigManager::New();
+        helper->setConfig( viewConfigID, replaceMap );
         helper->launch();
         helper->stopAndDestroy();
     }
@@ -403,27 +445,44 @@ void SActivityLauncher::buildActivity(const ::fwActivities::registry::ActivityIn
 
 //------------------------------------------------------------------------------
 
-void SActivityLauncher::sendConfig( const ::fwActivities::registry::ActivityInfo & info )
+void SActivityLauncher::sendConfig( const ::fwActivities::registry::ActivityInfo& info )
 {
+    // Start Bundle containing the activity if it is not started
+    std::shared_ptr< ::fwRuntime::Bundle > bundle = ::fwRuntime::findBundle(info.bundleId, info.bundleVersion);
+    SLM_WARN_IF("Bundle '" + info.bundleId + "' used by activity '" + info.id + "' is already started.",
+                bundle->isStarted());
+    if (!bundle->isStarted())
+    {
+        SLM_DEBUG("Start bundle '" + info.bundleId + "' used by activity '" + info.id + "'");
+        bundle->start();
+    }
+
     ::fwData::Vector::sptr selection = this->getObject< ::fwData::Vector >();
 
-    if(!info.validatorImpl.empty())
+    ::fwActivities::IValidator::ValidationType validation;
+    validation.first = true;
+
+    for(auto const& validatorImpl :  info.validatorsImpl)
     {
-        ::fwActivities::IValidator::sptr validator = ::fwActivities::validator::factory::New(info.validatorImpl);
-        OSLM_ASSERT(info.validatorImpl << " instantiation failed", validator);
+        ::fwActivities::IValidator::sptr validator = ::fwActivities::validator::factory::New(validatorImpl);
+        OSLM_ASSERT(validatorImpl << " instantiation failed", validator);
 
         ::fwActivities::IValidator::ValidationType valid = validator->validate(info, selection);
+        validation.first                                &= valid.first;
         if(!valid.first)
         {
-            ::fwGui::dialog::MessageDialog::showMessageDialog("Activity could not be launched",
-                    "The activity " + info.title + " can't be launched.\nReason : " + valid.second,
-                    ::fwGui::dialog::MessageDialog::WARNING);
-        }
-        else
-        {
-            this->buildActivity(info, selection);
+            validation.second += "\n" + valid.second;
         }
     }
+
+    if(!validation.first)
+    {
+        ::fwGui::dialog::MessageDialog::showMessageDialog(
+            "Activity can not be launched",
+            "The activity " + info.title + " can't be launched. Reason : " + validation.second,
+            ::fwGui::dialog::IMessageDialog::WARNING
+            );
+    }
     else
     {
         this->buildActivity(info, selection);
@@ -432,14 +491,14 @@ void SActivityLauncher::sendConfig( const ::fwActivities::registry::ActivityInfo
 
 //------------------------------------------------------------------------------
 
-bool SActivityLauncher::launchAS(::fwData::Vector::sptr &selection)
+bool SActivityLauncher::launchAS(::fwData::Vector::sptr& selection)
 {
     bool launchAS = false;
     ::fwActivities::registry::ActivityInfo::DataCountType dataCount;
     dataCount = ::fwActivities::registry::Activities::getDefault()->getDataCount(selection);
     if(dataCount.size() == 1)
     {
-        BOOST_FOREACH(::fwData::Object::sptr obj, *selection)
+        for(::fwData::Object::sptr obj :  *selection)
         {
             ::fwMedData::ActivitySeries::sptr as = ::fwMedData::ActivitySeries::dynamicCast(obj);
             if (!as)
@@ -449,12 +508,7 @@ bool SActivityLauncher::launchAS(::fwData::Vector::sptr &selection)
             }
             else
             {
-                ::fwActivities::registry::ActivityInfo info;
-                info = ::fwActivities::registry::Activities::getDefault()->getInfo(as->getActivityConfigId());
-                ParametersType parameters = this->translateParameters(m_parameters);
-                ::fwServices::ObjectMsg::sptr msg = helper::buildActivityMsg(as, info, parameters);
-
-                fwServicesNotifyMsgMacro(this->getLightID(), m_sigActivityLaunched, msg);
+                this->launchActivitySeries(as);
                 launchAS = true;
             }
         }
@@ -469,12 +523,7 @@ void SActivityLauncher::launchSeries(::fwMedData::Series::sptr series)
     ::fwMedData::ActivitySeries::sptr as = ::fwMedData::ActivitySeries::dynamicCast(series);
     if (as)
     {
-        ::fwActivities::registry::ActivityInfo info;
-        info = ::fwActivities::registry::Activities::getDefault()->getInfo(as->getActivityConfigId());
-        ParametersType parameters = this->translateParameters(m_parameters);
-        ::fwServices::ObjectMsg::sptr msg = helper::buildActivityMsg(as, info, parameters);
-
-        fwServicesNotifyMsgMacro(this->getLightID(), m_sigActivityLaunched, msg);
+        this->launchActivitySeries(as);
     }
     else
     {
@@ -486,10 +535,10 @@ void SActivityLauncher::launchSeries(::fwMedData::Series::sptr series)
         {
             std::string activityId = m_quickLaunch[ series->getClassname() ];
             SLM_ASSERT("Activity information not found for" + activityId,
-                    ::fwActivities::registry::Activities::getDefault()->hasInfo(activityId) );
+                       ::fwActivities::registry::Activities::getDefault()->hasInfo(activityId) );
             this->sendConfig( ::fwActivities::registry::Activities::getDefault()->getInfo(activityId) );
         }
-        else if ( ! infos.empty() )
+        else if ( !infos.empty() )
         {
             this->sendConfig( infos.front() );
         }
@@ -504,16 +553,56 @@ void SActivityLauncher::launchSeries(::fwMedData::Series::sptr series)
 
 //------------------------------------------------------------------------------
 
+void SActivityLauncher::launchActivitySeries(::fwMedData::ActivitySeries::sptr series)
+{
+    ::fwActivities::registry::ActivityInfo info;
+    info = ::fwActivities::registry::Activities::getDefault()->getInfo(series->getActivityConfigId());
+
+    // Applies activity validator on activity series to check the data
+    if (!info.validatorsImpl.empty())
+    {
+        for (std::string validatorImpl : info.validatorsImpl)
+        {
+            /// Process activity validator
+            ::fwActivities::IValidator::sptr validator = ::fwActivities::validator::factory::New(validatorImpl);
+
+            ::fwActivities::IActivityValidator::sptr activityValidator =
+                ::fwActivities::IActivityValidator::dynamicCast(validator);
+
+            if (activityValidator)
+            {
+                ::fwActivities::IValidator::ValidationType validation = activityValidator->validate(series);
+                if(!validation.first)
+                {
+                    std::string message = "The activity '" + info.title + "' can not be launched:\n" +
+                                          validation.second;
+                    ::fwGui::dialog::MessageDialog::showMessageDialog("Activity launch",
+                                                                      message,
+                                                                      ::fwGui::dialog::IMessageDialog::CRITICAL);
+                    return;
+                }
+            }
+        }
+    }
+
+    ParametersType parameters = this->translateParameters(m_parameters);
+    ::fwActivities::registry::ActivityMsg msg = ::fwActivities::registry::ActivityMsg(series, info, parameters);
+
+    m_sigActivityLaunched->asyncEmit(msg);
+}
+
+//------------------------------------------------------------------------------
+
 SActivityLauncher::ParametersType SActivityLauncher::translateParameters( const ParametersType& parameters )
 {
     ParametersType transParams = parameters;
     ::fwData::Object::sptr workingObj = this->getObject();
-    BOOST_FOREACH(ParametersType::value_type& param, transParams)
+    for(ParametersType::value_type& param :  transParams)
     {
         if(param.isSeshat())
         {
             std::string parameterToReplace = param.by;
-            if (parameterToReplace.substr(0,1) == "!")
+            if (parameterToReplace.substr(0, 1) == "!")
             {
                 parameterToReplace.replace(0, 1, "@");
             }
@@ -525,7 +614,7 @@ SActivityLauncher::ParametersType SActivityLauncher::translateParameters( const
 
             std::string parameterValue = obj->getID();
 
-            if(stringParameter && param.by.substr(0,1) == "!")
+            if(stringParameter && param.by.substr(0, 1) == "!")
             {
                 parameterValue = stringParameter->getValue();
             }
@@ -535,6 +624,18 @@ SActivityLauncher::ParametersType SActivityLauncher::translateParameters( const
     return transParams;
 }
 
-}
+//------------------------------------------------------------------------------
+
+::fwServices::IService::KeyConnectionsType SActivityLauncher::getObjSrvConnections() const
+{
+    KeyConnectionsType connections;
+    connections.push_back( std::make_pair( ::fwData::Vector::s_ADDED_OBJECTS_SIG, s_UPDATE_STATE_SLOT ) );
+    connections.push_back( std::make_pair( ::fwData::Vector::s_REMOVED_OBJECTS_SIG, s_UPDATE_STATE_SLOT ) );
+
+    return connections;
 }
 
+//------------------------------------------------------------------------------
+
+}
+}
