@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -21,10 +21,12 @@ struct FileAutoDelete;
 class FWMEMORY_CLASS_API FileHolder
 {
 public:
-    FileHolder(){};
+    FileHolder()
+    {
+    }
     FWMEMORY_API FileHolder(const ::boost::filesystem::path &file, bool autodelete = false);
 
-    operator ::boost::filesystem::path () const
+    operator :: boost::filesystem::path () const
     {
         return m_path;
     }
