@@ -1,18 +1,18 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWMEMORY_WIN32MEMORYMONITORTOOLS_HPP_
-#define _FWMEMORY_WIN32MEMORYMONITORTOOLS_HPP_
+#ifndef __FWMEMORY_TOOLS_WIN32MEMORYMONITORTOOLS_HPP__
+#define __FWMEMORY_TOOLS_WIN32MEMORYMONITORTOOLS_HPP__
 
 #ifdef _WIN32
 
-#include <boost/cstdint.hpp>
-
 #include "fwMemory/config.hpp"
 
+#include <cstdint>
+
 namespace fwMemory
 {
 namespace tools
@@ -23,15 +23,11 @@ class FWMEMORY_CLASS_API Win32MemoryMonitorTools
 
 public:
 
-    FWMEMORY_API Win32MemoryMonitorTools() ;
-
-    FWMEMORY_API ~Win32MemoryMonitorTools() ;
-
-
-
-    FWMEMORY_API static ::boost::uint64_t estimateFreeMem();
+    FWMEMORY_API Win32MemoryMonitorTools();
 
+    FWMEMORY_API ~Win32MemoryMonitorTools();
 
+    FWMEMORY_API static std::uint64_t estimateFreeMem();
 
     FWMEMORY_API static void printProcessMemoryInformation();
 
@@ -39,18 +35,13 @@ public:
 
     FWMEMORY_API static void printMemoryInformation();
 
+    FWMEMORY_API static std::uint64_t getTotalSystemMemory();
 
+    FWMEMORY_API static std::uint64_t getUsedSystemMemory();
 
-    FWMEMORY_API static ::boost::uint64_t getTotalSystemMemory();
-
-    FWMEMORY_API static ::boost::uint64_t getUsedSystemMemory();
-
-    FWMEMORY_API static ::boost::uint64_t getFreeSystemMemory();
-
-
-
-    FWMEMORY_API static ::boost::uint64_t getUsedProcessMemory();
+    FWMEMORY_API static std::uint64_t getFreeSystemMemory();
 
+    FWMEMORY_API static std::uint64_t getUsedProcessMemory();
 
 };
 
@@ -59,4 +50,4 @@ public:
 
 #endif
 
-#endif // _FWMEMORY_WIN32MEMORYMONITORTOOLS_HPP_
+#endif // __FWMEMORY_TOOLS_WIN32MEMORYMONITORTOOLS_HPP__
