@@ -1,13 +1,12 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWRUNTIME_PLUGIN_HPP_
-#define _FWRUNTIME_PLUGIN_HPP_
+#ifndef __FWRUNTIME_PLUGIN_HPP__
+#define __FWRUNTIME_PLUGIN_HPP__
 
-#include <boost/shared_ptr.hpp>
 
 #include "fwRuntime/config.hpp"
 #include "fwRuntime/IPlugin.hpp"
@@ -25,7 +24,7 @@ namespace fwRuntime
  * function must be implemented.
  *
  * @date    2004-2009
- * 
+ *
  */
 struct FWRUNTIME_CLASS_API Plugin : public IPlugin
 {
@@ -34,23 +33,23 @@ struct FWRUNTIME_CLASS_API Plugin : public IPlugin
      * @name    Overrides
      */
     //@{
-    FWRUNTIME_API ::boost::shared_ptr<Bundle> getBundle() const throw();
-    FWRUNTIME_API virtual void setInitializationData(const SPTR(ConfigurationElement) configuration) throw();
+    FWRUNTIME_API std::shared_ptr<Bundle> getBundle() const noexcept;
+    FWRUNTIME_API virtual void setInitializationData(const SPTR(ConfigurationElement)configuration) noexcept;
     //@}
 
 
-protected:
+    protected:
 
-    // Overrides
-    FWRUNTIME_API void setBundle( ::boost::shared_ptr<Bundle> bundle) throw();
+        // Overrides
+        FWRUNTIME_API void setBundle( std::shared_ptr<Bundle> bundle) noexcept;
 
 
-private:
+    private:
 
-    /**
-     * @brief   a pointer to the bundle the plugin is attached to
-     */
-     ::boost::shared_ptr<Bundle> m_bundle;
+        /**
+         * @brief   a pointer to the bundle the plugin is attached to
+         */
+        std::shared_ptr<Bundle> m_bundle;
 
 };
 
@@ -58,4 +57,4 @@ private:
 } // namespace fwRuntime
 
 
-#endif //_FWRUNTIME_PLUGIN_HPP_
+#endif //__FWRUNTIME_PLUGIN_HPP__
