@@ -1,17 +1,18 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWRUNTIME_PROFILE_INITIALIZER_HPP_
-#define _FWRUNTIME_PROFILE_INITIALIZER_HPP_
-
-#include <string>
-#include <boost/utility.hpp>
+#ifndef __FWRUNTIME_PROFILE_INITIALIZER_HPP__
+#define __FWRUNTIME_PROFILE_INITIALIZER_HPP__
 
 #include "fwRuntime/config.hpp"
+#include "fwRuntime/Version.hpp"
 
+#include <boost/utility.hpp>
+
+#include <string>
 
 namespace fwRuntime
 {
@@ -19,13 +20,8 @@ namespace fwRuntime
 namespace profile
 {
 
-
-
 /**
  * @brief   Starts a given bundle.
- * @class  Initializer
- * @date    2007-2009
- * 
  */
 class Initializer : public boost::noncopyable
 {
@@ -37,7 +33,7 @@ public:
      *
      * @param[in]   identifier  a string containing a bundle identifier
      */
-    FWRUNTIME_API Initializer( const std::string & identifier );
+    FWRUNTIME_API Initializer( const std::string& identifier, const Version& version = Version() );
 
     /**
      * @brief   Applies the initializer on the bundle.
@@ -46,19 +42,15 @@ public:
      */
     void apply();
 
-
 protected:
 
-    const std::string   m_identifier;   ///< a bundle identifier
+    const std::string m_identifier;     ///< the bundle identifier
+    const Version m_version;            ///< the bundle version
 
 };
 
-
-
 } // namespace profile
 
 } // namespace fwRuntime
 
-
-
-#endif /*_FWRUNTIME_PROFILE_INITIALIZER_HPP_*/
+#endif /*__FWRUNTIME_PROFILE_INITIALIZER_HPP__*/
