@@ -1,66 +1,35 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
+#include "fwRuntime/Bundle.hpp"
+
+#include "fwRuntime/EmptyPlugin.hpp"
+#include "fwRuntime/ExecutableFactory.hpp"
+#include "fwRuntime/Extension.hpp"
+#include "fwRuntime/ExtensionPoint.hpp"
+#include "fwRuntime/IExecutable.hpp"
+#include "fwRuntime/io/BundleDescriptorReader.hpp"
+#include "fwRuntime/profile/Initializer.hpp"
+#include "fwRuntime/profile/Profile.hpp"
+#include "fwRuntime/profile/Stopper.hpp"
+#include "fwRuntime/Runtime.hpp"
+#include "fwRuntime/utils/GenericExecutableFactory.hpp"
+
+#include <fwCore/base.hpp>
 
 #include <algorithm>
 #include <cassert>
 #include <exception>
 #include <memory>
 
-#include <fwCore/base.hpp>
-
-#include "fwRuntime/EmptyPlugin.hpp"
-#include "fwRuntime/IExecutable.hpp"
-#include "fwRuntime/ExecutableFactory.hpp"
-#include "fwRuntime/Extension.hpp"
-#include "fwRuntime/ExtensionPoint.hpp"
-#include "fwRuntime/predicates.hpp"
-#include "fwRuntime/Runtime.hpp"
-#include "fwRuntime/io/BundleDescriptorReader.hpp"
-#include "fwRuntime/utils/GenericExecutableFactory.hpp"
-#include "fwRuntime/profile/Profile.hpp"
-#include "fwRuntime/profile/Initializer.hpp"
-#include "fwRuntime/profile/Stopper.hpp"
-
-#include "fwRuntime/Bundle.hpp"
-
-
 namespace fwRuntime
 {
 
 //------------------------------------------------------------------------------
 
-namespace
-{
-
-    /**
-     * @brief   Defines a STL compatible predicate telling if an executable factory
-     *          matches the given type identifier
-     *
-     * 
-     */
-    struct IsOfType
-    {
-        IsOfType( const std::string & type )
-        :   m_type( type )
-        {}
-
-        bool operator() ( const SPTR( ExecutableFactory ) factory ) const
-        {
-            return factory->getType() == m_type;
-        }
-
-    private:
-
-        std::string m_type;
-    };
-}
-
-//------------------------------------------------------------------------------
-
 SPTR( Bundle ) Bundle::m_loadingBundle;
 
 //------------------------------------------------------------------------------
@@ -72,44 +41,41 @@ SPTR( Bundle ) Bundle::getLoadingBundle()
 
 //------------------------------------------------------------------------------
 
-Bundle::Bundle( const boost::filesystem::path   & location,
-                const std::string               & id,
-                const std::string               & version )
-:   m_location    ( location ),
-    m_identifier  ( id ),
-    m_version     ( version ),
-    m_enable      ( false ),
-    m_started     ( false ),
-    m_initialized ( false )
-
+Bundle::Bundle( const ::boost::filesystem::path& location,
+                const std::string& id,
+                const std::string& version ) :
+    Bundle(location, id, version, "")
 {
-    // Post-condition.
-    assert( m_location.is_complete() == true );
 }
 
 //------------------------------------------------------------------------------
 
-Bundle::Bundle(
-            const boost::filesystem::path   & location,
-            const std::string               & id,
-            const std::string               & version,
-            const std::string               & c )
-:   m_location    ( location ),
-    m_identifier  ( id ),
-    m_version     ( version ),
-    m_class       ( c ),
-    m_enable      ( false ),
-    m_started     ( false ),
-    m_initialized ( false )
-
+Bundle::Bundle( const ::boost::filesystem::path& location,
+                const std::string& id,
+                const std::string& version,
+                const std::string& c ) :
+    m_resourcesLocation( location.lexically_normal() ),
+    m_identifier( id ),
+    m_version( version ),
+    m_class( c )
 {
     // Post-condition.
-    assert( m_location.is_complete() == true );
+    SLM_ASSERT( "Invalid bundle location.",  m_resourcesLocation.is_complete() == true );
+
+    // Starting from FW4SPL 13.0, the plugin.xml is now likely to be separated from the libraries in the build/install
+    std::string strLocation       = location.string();
+    const std::string strRCPrefix = BUNDLE_RC_PREFIX;
+    const auto itBundle           = strLocation.find(strRCPrefix);
+    if(itBundle != std::string::npos)
+    {
+        strLocation.replace(itBundle, strRCPrefix.length(), std::string(BUNDLE_LIB_PREFIX));
+    }
+    m_libraryLocation = ::boost::filesystem::path(strLocation);
 }
 
 //------------------------------------------------------------------------------
 
-void Bundle::addExecutableFactory( SPTR( ExecutableFactory ) factory )
+void Bundle::addExecutableFactory( SPTR( ExecutableFactory )factory )
 {
     m_executableFactories.insert( factory );
 }
@@ -132,46 +98,50 @@ Bundle::ExecutableFactoryConstIterator Bundle::executableFactoriesEnd() const
 
 SPTR( ExecutableFactory ) Bundle::findExecutableFactory( const std::string & type ) const
 {
-    ExecutableFactoryConstIterator  found = std::find_if( m_executableFactories.begin(), m_executableFactories.end(), IsOfType(type) );
-    return found != m_executableFactories.end() ? *found : SPTR( ExecutableFactory )();
+    std::shared_ptr<ExecutableFactory> resExecutableFactory;
+    for(const ExecutableFactoryContainer::value_type& factory : m_executableFactories)
+    {
+        if(factory->getType() == type)
+        {
+            resExecutableFactory = factory;
+            break;
+        }
+    }
+    return resExecutableFactory;
 }
 
 //------------------------------------------------------------------------------
 
-void Bundle::addExtension( SPTR( Extension ) extension )
+void Bundle::addExtension( SPTR( Extension )extension )
 {
     m_extensions.insert( extension );
 }
 
 //------------------------------------------------------------------------------
 
-bool Bundle::hasExtension(const std::string & identifier) const
+bool Bundle::hasExtension(const std::string& identifier) const
 {
-    ExtensionContainer::const_iterator extpt = m_extensions.begin();
-    while( extpt != m_extensions.end() )
+    bool hasExtension = false;
+    for(const ExtensionContainer::value_type& extension : m_extensions)
     {
-        if( (*extpt)->getIdentifier() ==  identifier )
+        if(extension->getIdentifier() == identifier)
         {
-            return true;
+            hasExtension = true;
+            break;
         }
-        ++extpt;
     }
-
-    return false;
+    return hasExtension;
 }
 
 //------------------------------------------------------------------------------
 
-void Bundle::setEnableExtension(const std::string & identifier, const bool enable)
+void Bundle::setEnableExtension(const std::string& identifier, const bool enable)
 {
-    for( ExtensionContainer::iterator extpt = m_extensions.begin();
-            extpt != m_extensions.end();
-            ++extpt )
+    for(const ExtensionContainer::value_type& extension : m_extensions)
     {
-
-        if( (*extpt)->getIdentifier() ==  identifier )
+        if(extension->getIdentifier() == identifier)
         {
-            (*extpt)->setEnable(enable);
+            extension->setEnable(enable);
             break; // The identifier is unique => can break the loop
         }
     }
@@ -192,7 +162,7 @@ Bundle::ExtensionConstIterator Bundle::extensionsEnd() const
 }
 //------------------------------------------------------------------------------
 
-void Bundle::addExtensionPoint( SPTR( ExtensionPoint ) extensionPoint )
+void Bundle::addExtensionPoint( SPTR( ExtensionPoint )extensionPoint )
 {
     m_extensionPoints.insert( extensionPoint );
 }
@@ -201,42 +171,44 @@ void Bundle::addExtensionPoint( SPTR( ExtensionPoint ) extensionPoint )
 
 SPTR( ExtensionPoint ) Bundle::findExtensionPoint( const std::string & identifier ) const
 {
-    ExtensionPointContainer::const_iterator found;
-
-    found = std::find_if( m_extensionPoints.begin(), m_extensionPoints.end(), IsEnableAndHasIdentifier<ExtensionPoint>(identifier) );
-    return (found != m_extensionPoints.end()) ? (*found) : SPTR(ExtensionPoint)();
-}
-
-//------------------------------------------------------------------------------
-
-bool Bundle::hasExtensionPoint(const std::string & identifier) const
-{
-    ExtensionPointContainer::const_iterator extpt = m_extensionPoints.begin();
-    while( extpt != m_extensionPoints.end() )
+    std::shared_ptr<ExtensionPoint> resExtensionPoint;
+    for(const ExtensionPointContainer::value_type& extensionPoint :  m_extensionPoints)
     {
-        if( (*extpt)->getIdentifier() ==  identifier )
+        if(extensionPoint->getIdentifier() == identifier && extensionPoint->isEnable())
         {
-            return true;
+            resExtensionPoint = extensionPoint;
+            break;
         }
-        ++extpt;
     }
-
-    return false;
+    return resExtensionPoint;
 }
 
 //------------------------------------------------------------------------------
 
-void Bundle::setEnableExtensionPoint(const std::string & identifier, const bool enable)
+bool Bundle::hasExtensionPoint(const std::string& identifier) const
 {
-    for( ExtensionPointContainer::iterator extpt = m_extensionPoints.begin();
-         extpt != m_extensionPoints.end();
-         ++extpt )
+    bool hasExtensionPoint = false;
+    for(const ExtensionPointContainer::value_type& extensionPoint :  m_extensionPoints)
     {
-
-        if( (*extpt)->getIdentifier() ==  identifier )
+        if(extensionPoint->getIdentifier() == identifier)
         {
-            (*extpt)->setEnable(enable);
-            break; // The identifier is unique => can break the loop
+            hasExtensionPoint = true;
+            break;
+        }
+    }
+    return hasExtensionPoint;
+}
+
+//------------------------------------------------------------------------------
+
+void Bundle::setEnableExtensionPoint(const std::string& identifier, const bool enable)
+{
+    for(const ExtensionPointContainer::value_type& extensionPoint :  m_extensionPoints)
+    {
+        if(extensionPoint->getIdentifier() == identifier)
+        {
+            extensionPoint->setEnable(enable);
+            break;
         }
     }
 }
@@ -257,7 +229,7 @@ Bundle::ExtensionPointConstIterator Bundle::extensionPointsEnd() const
 
 //------------------------------------------------------------------------------
 
-void Bundle::addLibrary( SPTR( dl::Library ) library )
+void Bundle::addLibrary( SPTR(dl::Library)library )
 {
     library->setBundle(this);
     m_libraries.insert(library);
@@ -279,7 +251,7 @@ Bundle::LibraryConstIterator Bundle::librariesEnd() const
 
 //------------------------------------------------------------------------------
 
-void Bundle::addRequirement(const std::string & requirement)
+void Bundle::addRequirement(const std::string& requirement)
 {
     m_requirements.insert(requirement);
 }
@@ -293,16 +265,23 @@ const std::string Bundle::getClass() const
 
 //------------------------------------------------------------------------------
 
-const std::string & Bundle::getIdentifier() const
+const std::string& Bundle::getIdentifier() const
 {
     return m_identifier;
 }
 
 //------------------------------------------------------------------------------
 
-const boost::filesystem::path & Bundle::getLocation() const
+const ::boost::filesystem::path& Bundle::getLibraryLocation() const
 {
-    return m_location;
+    return m_libraryLocation;
+}
+
+//------------------------------------------------------------------------------
+
+const ::boost::filesystem::path& Bundle::getResourcesLocation() const
+{
+    return m_resourcesLocation;
 }
 
 //------------------------------------------------------------------------------
@@ -314,42 +293,39 @@ SPTR( IPlugin ) Bundle::getPlugin() const
 
 //------------------------------------------------------------------------------
 
-const Version & Bundle::getVersion() const
+const Version& Bundle::getVersion() const
 {
     return m_version;
 }
 
 //------------------------------------------------------------------------------
 
-void Bundle::loadLibraries() throw(RuntimeException)
+void Bundle::loadLibraries()
 {
     // Ensure the bundle is enabled.
     if( m_enable == false )
     {
-        throw RuntimeException( m_identifier + ": bundle is not enabled." );
+        throw RuntimeException( getBundleStr(m_identifier, m_version) + ": bundle is not enabled." );
     }
 
     // Pre-condition
     SLM_ASSERT("Bundle is already loaded", m_loadingBundle == 0 );
 
-    OSLM_TRACE( "Loading " << this->getIdentifier() << " library...");
+    SLM_TRACE( "Loading " + this->getIdentifier() + s_VERSION_DELIMITER + this->getVersion().string() + " library...");
 
     // References the current bundle as the loading bundle.
     m_loadingBundle = shared_from_this();
 
     // Loads all libraries.
-    LibraryContainer::iterator curEntry;
-    LibraryContainer::iterator endEntry = m_libraries.end();
-    for(curEntry = m_libraries.begin(); curEntry != endEntry; ++curEntry)
+    for(const LibraryContainer::value_type& library : m_libraries)
     {
-        SPTR(dl::Library) library(*curEntry);
         if(library->isLoaded() == false)
         {
             try
             {
                 library->load();
             }
-            catch( std::exception & e )
+            catch( std::exception& e )
             {
                 std::string message;
 
@@ -371,22 +347,20 @@ void Bundle::loadLibraries() throw(RuntimeException)
 
     // Post-condition
     assert( m_loadingBundle == 0 );
-
-    OSLM_TRACE(this->getIdentifier() << " library loaded");
+    SLM_TRACE("Library " + getBundleStr(m_identifier, m_version) + " loaded");
 }
 
 //------------------------------------------------------------------------------
 
-void Bundle::loadRequirements() throw(RuntimeException)
+void Bundle::loadRequirements()
 {
     try
     {
-        Runtime *rntm(Runtime::getDefault());
+        Runtime* rntm(Runtime::getDefault());
         RequirementContainer::const_iterator iter;
-        for(iter = m_requirements.begin(); iter != m_requirements.end(); ++iter)
+        for(const RequirementContainer::value_type& requirement : m_requirements)
         {
-            const std::string requirement ( *iter);
-            SPTR( Bundle ) bundle( rntm->findBundle(requirement) );
+            SPTR( Bundle ) bundle( rntm->findEnabledBundle(requirement) );
 
             // Ensure that a bundle has been retrieved.
             if( bundle == 0 )
@@ -400,11 +374,11 @@ void Bundle::loadRequirements() throw(RuntimeException)
             }
         }
     }
-    catch( const std::exception & e )
+    catch( const std::exception& e )
     {
         std::string message;
 
-        message += "Bundle " + getIdentifier() + " was not able to load requirements. ";
+        message += "Bundle " + getBundleStr(m_identifier, m_version) + " was not able to load requirements. ";
         message += e.what();
         throw RuntimeException( message );
     }
@@ -412,12 +386,13 @@ void Bundle::loadRequirements() throw(RuntimeException)
 
 //------------------------------------------------------------------------------
 
-void Bundle::start() throw(RuntimeException)
+void Bundle::start()
 {
-    OSLM_ASSERT("Bundle "<< this->getIdentifier() << " already started.", !m_started );
+    SLM_ASSERT("Bundle " + getBundleStr(m_identifier, m_version) + " already started.",
+               !m_started );
     if( m_enable == false )
     {
-        throw RuntimeException( m_identifier + ": bundle is not enabled." );
+        throw RuntimeException( getBundleStr(m_identifier, m_version) + ": bundle is not enabled." );
     }
 
     if( m_plugin == 0 )
@@ -427,22 +402,24 @@ void Bundle::start() throw(RuntimeException)
         try
         {
             startPlugin();
-            OSLM_TRACE(this->getIdentifier() << " Started");
+            SLM_TRACE(getBundleStr(m_identifier, m_version) + " Started");
         }
-        catch( std::exception & e )
+        catch( std::exception& e )
         {
-            throw RuntimeException( m_identifier + ": start plugin error (after load requirement) :" + e.what() );
+            throw RuntimeException( getBundleStr(m_identifier, m_version) +
+                                    ": start plugin error (after load requirement) :" + e.what() );
         }
     }
 }
 
 //------------------------------------------------------------------------------
 
-void Bundle::startPlugin() throw(RuntimeException)
+void Bundle::startPlugin()
 {
-    OSLM_ASSERT("Bundle "<< this->getIdentifier() << " plugin is already started.", !m_started );
+    SLM_ASSERT("Bundle " + getBundleStr(m_identifier, m_version) + " plugin is already started.",
+               !m_started );
     // Retrieves the type of the plugin.
-    const std::string   pluginType( getClass() );
+    const std::string pluginType( getClass() );
 
     // According to the presence of a class or not, build and empty
     // plugin or attempt to instantiate a user defined plugin.
@@ -454,53 +431,55 @@ void Bundle::startPlugin() throw(RuntimeException)
     }
     else
     {
-        Runtime * rntm  ( Runtime::getDefault() );
-        SPTR( IExecutable ) executable ( rntm->createExecutableInstance(pluginType) );
+        Runtime* rntm( Runtime::getDefault() );
+        SPTR( IExecutable ) executable( rntm->createExecutableInstance(pluginType) );
 
-        plugin = ::boost::dynamic_pointer_cast< IPlugin >( executable );
+        plugin = std::dynamic_pointer_cast< IPlugin >( executable );
     }
 
     // Ensures that a plugin has been created.
     if( plugin == 0 )
     {
-        throw RuntimeException( getIdentifier() + ": unable to create a plugin instance." );
+        throw RuntimeException( getBundleStr(m_identifier, m_version) + ": unable to create a plugin instance." );
     }
 
-    OSLM_TRACE("Starting " << this->getIdentifier() << " Bundle's plugin.");
+    SLM_TRACE("Starting " + getBundleStr(m_identifier, m_version) + " Bundle's plugin.");
     // Stores and start the plugin.
     try
     {
-        OSLM_TRACE("Register stopper for " << this->getIdentifier() << " Bundle's plugin.");
-        ::fwRuntime::profile::getCurrentProfile()->add( SPTR(profile::Stopper) (new profile::Stopper(this->getIdentifier())));
+        SLM_TRACE("Register stopper for " + getBundleStr(m_identifier, m_version) + " Bundle's plugin.");
+        ::fwRuntime::profile::getCurrentProfile()->add(
+            SPTR(profile::Stopper) (new profile::Stopper(this->getIdentifier(), this->getVersion())));
         m_plugin = plugin;
         m_plugin->start();
-        ::fwRuntime::profile::getCurrentProfile()->add( SPTR(profile::Initializer) (new profile::Initializer(this->getIdentifier())) );
+        ::fwRuntime::profile::getCurrentProfile()->add(
+            SPTR(profile::Initializer) (new profile::Initializer(this->getIdentifier(), this->getVersion())) );
         m_started = true;
     }
-    catch( std::exception & e )
+    catch( std::exception& e )
     {
-        throw RuntimeException( getIdentifier() + ": start plugin error : " + e.what() );
+        throw RuntimeException( getBundleStr(m_identifier, m_version) + ": start plugin error : " + e.what() );
     }
 }
 
 //------------------------------------------------------------------------------
 
-void Bundle::stop() throw(RuntimeException)
+void Bundle::stop()
 {
-    OSLM_ASSERT("Bundle "<< this->getIdentifier() << " not started.", m_started );
-    OSLM_ASSERT(this->getIdentifier() << " : m_plugin not an intance.", m_plugin != 0 );
-    OSLM_ASSERT("Bundle "<< this->getIdentifier() << " not uninitialized.", !m_initialized );
+    SLM_ASSERT("Bundle "+ getBundleStr(m_identifier, m_version) + " not started.", m_started );
+    SLM_ASSERT(getBundleStr(m_identifier, m_version) + " : m_plugin not an intance.", m_plugin != 0 );
+    SLM_ASSERT("Bundle " + getBundleStr(m_identifier, m_version) + " not uninitialized.", !m_initialized );
 
-    OSLM_TRACE("Stopping " << this->getIdentifier() << "Bundle's plugin.");
+    SLM_TRACE("Stopping " + getBundleStr(m_identifier, m_version) + " Bundle's plugin.");
     try
     {
         m_plugin->stop();
         m_started = false;
-        OSLM_TRACE(this->getIdentifier() << " Stopped");
+        OSLM_TRACE(getBundleStr(m_identifier, m_version) << " Stopped");
     }
-    catch( std::exception & e )
+    catch( std::exception& e )
     {
-        throw RuntimeException( this->getIdentifier() + ": stop plugin error : " + e.what() );
+        throw RuntimeException( getBundleStr(m_identifier, m_version) + ": stop plugin error : " + e.what() );
     }
 
     ::fwRuntime::Runtime::getDefault()->unregisterBundle(this->shared_from_this());
@@ -510,7 +489,7 @@ void Bundle::stop() throw(RuntimeException)
 //    LibraryContainer::iterator endEntry = m_libraries.end();
 //    for(curEntry = m_libraries.begin(); curEntry != endEntry; ++curEntry)
 //    {
-//        ::boost::shared_ptr<dl::Library> library(*curEntry);
+//        std::shared_ptr<dl::Library> library(*curEntry);
 //        if(library->isLoaded() == true )
 //        {
 //            library->unload();
@@ -519,39 +498,39 @@ void Bundle::stop() throw(RuntimeException)
 }
 
 //------------------------------------------------------------------------------
-void Bundle::initialize() throw(RuntimeException)
+void Bundle::initialize()
 {
-    OSLM_ASSERT("Bundle "<< this->getIdentifier() << " not started.", m_started );
-    OSLM_ASSERT("Bundle "<< this->getIdentifier() << " already initialized.", !m_initialized );
+    SLM_ASSERT("Bundle '" + getBundleStr(m_identifier, m_version) + "' not started.", m_started );
+    SLM_ASSERT("Bundle '"+ getBundleStr(m_identifier, m_version) + "' already initialized.", !m_initialized );
     try
     {
         m_initialized = true;
-        OSLM_TRACE("Initializing " << this->getIdentifier() << " ...");
+        SLM_TRACE("Initializing " + getBundleStr(m_identifier, m_version) + " ...");
         m_plugin->initialize();
-        OSLM_TRACE("             " <<this->getIdentifier() << " Initialized");
+        SLM_TRACE("             " + getBundleStr(m_identifier, m_version) + " Initialized");
     }
-    catch( std::exception & e )
+    catch( std::exception& e )
     {
-        throw RuntimeException( this->getIdentifier() + ": initialize plugin error : " + e.what() );
+        throw RuntimeException( getBundleStr(m_identifier, m_version) + ": initialize plugin error : " + e.what() );
     }
 }
 
 //------------------------------------------------------------------------------
 
-void Bundle::uninitialize() throw(RuntimeException)
+void Bundle::uninitialize()
 {
-    OSLM_ASSERT("Bundle "<< this->getIdentifier() << " has not been started.", m_plugin );
-    OSLM_ASSERT("Bundle "<< this->getIdentifier() << " not initialized.", m_initialized );
+    SLM_ASSERT("Bundle '"+ getBundleStr(m_identifier, m_version) + "' has not been started.", m_plugin );
+    SLM_ASSERT("Bundle '"+ getBundleStr(m_identifier, m_version) + "' not initialized.", m_initialized );
     try
     {
-        OSLM_TRACE("Uninitializing " << this->getIdentifier() << " ...");
+        SLM_TRACE("Uninitializing " + this->getIdentifier() + " ...");
         m_plugin->uninitialize();
         m_initialized = false;
-        OSLM_TRACE("               " << this->getIdentifier() << " Uninitialized");
+        SLM_TRACE("               " + this->getIdentifier() + " Uninitialized");
     }
-    catch( std::exception & e )
+    catch( std::exception& e )
     {
-        throw RuntimeException( this->getIdentifier() + ": initialize plugin error : " + e.what() );
+        throw RuntimeException( getBundleStr(m_identifier, m_version) + ": initialize plugin error : " + e.what() );
     }
 }
 
@@ -571,31 +550,39 @@ void Bundle::setEnable( const bool state )
 
 //------------------------------------------------------------------------------
 
-void Bundle::addParameter( const std::string & identifier, const std::string & value )
+void Bundle::addParameter( const std::string& identifier, const std::string& value )
 {
     m_parameters[identifier] = value;
 }
 
 //------------------------------------------------------------------------------
 
-const std::string Bundle::getParameterValue( const std::string & identifier ) const
+const std::string Bundle::getParameterValue( const std::string& identifier ) const
 {
-    ParameterContainer::const_iterator  found = m_parameters.find(identifier);
+    ParameterContainer::const_iterator found = m_parameters.find(identifier);
 
     return (found != m_parameters.end()) ? found->second : std::string();
 }
 
 //------------------------------------------------------------------------------
 
-bool Bundle::hasParameter( const std::string & identifier ) const
+bool Bundle::hasParameter( const std::string& identifier ) const
 {
     return (m_parameters.find(identifier) != m_parameters.end());
 }
 
 //------------------------------------------------------------------------------
 
-void Bundle::operator= ( const Bundle & )
-{}
+std::string fwRuntime::Bundle::getBundleStr(const std::string& identifier, const fwRuntime::Version& version)
+{
+    return identifier + s_VERSION_DELIMITER + version.string();
+}
+
+//------------------------------------------------------------------------------
+
+void Bundle::operator= ( const Bundle& )
+{
+}
 
 //------------------------------------------------------------------------------
 
