@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -9,6 +9,8 @@
 
 #include "fwMDSemanticPatch/config.hpp"
 
+#include <string>
+
 namespace fwMDSemanticPatch
 {
 
@@ -18,6 +20,9 @@ class PatchLoader
 public:
     /// Computes VersionsManager's link and version tables.
     FWMDSEMANTICPATCH_API static void loadPatches();
+
+    /// Returns current MedicalData version.
+    FWMDSEMANTICPATCH_API static std::string getCurrentVersion();
 };
 
 } //namespace fwMDSemanticPatch
