@@ -1,27 +1,34 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <boost/chrono/duration.hpp>
 #include "fwTest/helper/Thread.hpp"
 
+#include <chrono>
+#include <functional>
+
 namespace fwTest
 {
 namespace helper
 {
 
-Thread::Thread(FunctionType f) :
-        m_hasFailed(false)
+//-----------------------------------------------------------------------------
+
+Thread::Thread(FunctionType f) : m_hasFailed(false)
 {
-    m_thread = ::boost::thread(::boost::bind(&Thread::run, this, f));
+    m_thread = std::thread(std::bind(&Thread::run, this, f));
 }
 
+//-----------------------------------------------------------------------------
+
 Thread::~Thread()
 {
 }
 
+//-----------------------------------------------------------------------------
+
 void Thread::join(bool raise)
 {
     m_thread.join();
@@ -31,9 +38,19 @@ void Thread::join(bool raise)
     }
 }
 
+//-----------------------------------------------------------------------------
+
 bool Thread::timedJoin(int time, bool raise)
 {
-    bool joined = m_thread.try_join_for(boost::chrono::milliseconds(time));
+    bool joined = false;
+
+    std::this_thread::sleep_for(std::chrono::milliseconds(time));
+    if (m_thread.joinable())
+    {
+        m_thread.join();
+        joined = true;
+    }
+
     if (raise)
     {
         this->throwException();
@@ -41,6 +58,8 @@ bool Thread::timedJoin(int time, bool raise)
     return joined;
 }
 
+//-----------------------------------------------------------------------------
+
 void Thread::throwException()
 {
     if (this->hasFailed())
@@ -49,6 +68,8 @@ void Thread::throwException()
     }
 }
 
+//-----------------------------------------------------------------------------
+
 void Thread::run(FunctionType f)
 {
     try
